package
module
Version:
v0.0.0-...-bbb3407
Opens a new window with list of versions in this module.
Published: Feb 1, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Queue[V any] interface {
Push(value V)
Pop() (value V, ok bool)
Len() int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.